#include "newreceta.h"
#include "ui_newreceta.h"
#include "editarreceta.h"

#include <fstream>
#include <string>
#include <iostream>
#include <QMessageBox>
#include <QFile>
#include <QTextStream>
#include <qdir.h>

/**
 * @brief NewReceta::NewReceta
 * Constructor de la clase encargada del manejo de ingreso de texto para su correcta ejecucion en la interfaz grafica.
 * @param parent Variable tipo Qwidget.
 */
NewReceta::NewReceta(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::NewReceta)
{
    ui->setupUi(this);
    this->setWindowFlags(this->windowFlags() & ~Qt::WindowContextHelpButtonHint);
    ui->NewProcedimiento->hide();
    ui->NewIngrediente->hide();
    ui->label_2->hide();
    ui->addNew->hide();

}

/**
 * @brief NewReceta::~NewReceta
 * Destructor de la clase.
 */
NewReceta::~NewReceta()
{
    delete ui;
}

/**
 * @brief NewReceta::on_SendNew_released
 * Verifica los parametros de ingreso.
 * Corrobora que los parametros ingresados no son valor NULL y si la receta ya existe, con la posibilidad de editarla.
 */
void NewReceta::on_SendNew_released()
{
    QString nombre=ui->lineEdit->text();
    if (nombre.isEmpty())
        /**
         * @brief QMessageBox::information
         * Advierte que debe ingresar un nombre cuando no se rellena el parametro.
         */
        QMessageBox::information(0,"Atención!","Debe ingresar un nombre");
    else
    {
        QFile listado("Listado.txt");
        listado.open(QIODevice::ReadOnly);
        QTextStream in(&listado);

        const QString content = in.readAll();
        if(content.contains(nombre,Qt::CaseInsensitive)){
            /**
             * @brief messageBox
             * Advierte que ya existe la receta que se esta ingresando como nueva.
             * Presenta la opcion de editarla.
             */
            QMessageBox messageBox(QMessageBox::NoIcon,
                tr("Receta ya ingresada"),
                tr("Su recetario ya contiene esta receta.\n¿Desea editar?"),
                QMessageBox::Yes | QMessageBox::No,
                this);
            messageBox.setButtonText(QMessageBox::Yes, tr("Sí"));
            messageBox.setButtonText(QMessageBox::No, tr("No"));
            if(messageBox.exec() == QMessageBox::Yes){
                this->close();
                EditarReceta edwndw;
                edwndw.setModal(true);
                edwndw.exec();}
            else
                this->close();
        }
        else{
            ui->lineEdit->setEnabled(false);
            ui->NewProcedimiento->setReadOnly(false);
            ui->NewIngrediente->setReadOnly(false);
        }
        listado.close();

        ui->SendNew->hide();
        ui->label_4->hide();
        ui->NewProcedimiento->show();
        ui->NewIngrediente->show();
        ui->label_2->show();
        ui->addNew->show();
    }
}

/**
 * @brief NewReceta::on_addNew_released
 * Agrega la receta en los directorios que corresponden para guardarla.
 */
void NewReceta::on_addNew_released()
{
    QString nombre=ui->lineEdit->text();
    QFile listado("Listado.txt");
    QFile archivo("Ingredientes/"+nombre+"_ing.txt");
    QFile file("Procedimiento/"+nombre+".txt");
    if(!archivo.open(QFile::WriteOnly | QFile::Text) || !file.open(QFile::WriteOnly | QFile::Text) || !listado.open(QIODevice::Append | QIODevice::Text))
        /**
         * @brief QMessageBox::information
         * Informa error de lectura o archivo no encontrado.
         */
        QMessageBox::information(0,"Error de lectura","Archivo no encontrado.\nVerifique escritura.");
    QTextStream send(&archivo);
    QTextStream out(&file);
    QTextStream in(&listado);
    if(ui->NewProcedimiento->toPlainText().isEmpty() || ui->NewIngrediente->toPlainText().isEmpty())
        /**
         * @brief QMessageBox::information
         * Advierte que no se han llenado los parametros necesarios para completar una receta.
         */
        QMessageBox::information(0,"Atención!","Ingrese procedimiento.");
    else{
        in << nombre << endl;
        out << ui->NewProcedimiento->toPlainText();
        send << ui->NewIngrediente->toPlainText();
        archivo.flush(); /** <Agrega los ingredientes ingresados al archivo correspondiente.*/
        file.flush(); /** <Agrega el procedimiento ingresado al archivo correspondiente.*/
        listado.flush(); /** <Agrega la nueva receta al archivo con el listado de recetas.*/
        archivo.close();
        file.close();
        listado.close();
        /**
         * @brief guardarreceta
         * Informa el correcto ingreso de la nueva receta y si se desea terminar la edicion.
         */
        QMessageBox guardarreceta(QMessageBox::NoIcon,
            tr("Guardar"),
            tr("Su receta se ha guardado exitósamente.\n¿Desea terminar la edición?"),
            QMessageBox::Yes | QMessageBox::No,
            this);
        guardarreceta.setButtonText(QMessageBox::Yes, tr("Sí"));
        guardarreceta.setButtonText(QMessageBox::No, tr("No"));
        if(guardarreceta.exec() == QMessageBox::Yes)
            this->close();
        else
            guardarreceta.close();
    }
}

/**
 * @brief NewReceta::on_VolverNew_released
 * Regresa a la ventana principal de opciones.
 * Funcion con el boton volver a la ventana principal de opciones con la condicion de desistir el ingreso de una nueva receta.
 */
void NewReceta::on_VolverNew_released()
{
    /**
     * @brief volver
     * Despliega un dialogo de advertencia para verificar la accion de abandonar la ventana para ingresar una nueva receta.
     */
    QMessageBox volver(QMessageBox::NoIcon,
        tr("Volver"),
        tr("Su receta no se ha guardado.\nSe perderán los cambios realizados.\n¿Está seguro de que desea volver?"),
        QMessageBox::Yes | QMessageBox::No,
        this);
    volver.setButtonText(QMessageBox::Yes, tr("Sí"));
    volver.setButtonText(QMessageBox::No, tr("No"));
    if(volver.exec() == QMessageBox::Yes)
        this->close();
    else
        volver.close();
}
