#include "verreceta.h"
#include "ui_verreceta.h"

#include <QFile>
#include <QTextStream>
#include <QMessageBox>
#include <qdesktopservices.h>
#include <qurl.h>

#include <iostream>

using namespace std;

/**
 * @brief VerReceta::VerReceta
 * Constructor de la clase encargada del manejo de archivos de texto para su correcta ejecucion en la interfaz grafica.
 * @param parent Variable tipo Qwidget.
 */
VerReceta::VerReceta(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::VerReceta)
{
    ui->setupUi(this);
    this->setWindowFlags(this->windowFlags() & ~Qt::WindowContextHelpButtonHint);
    ui->VerNombre->hide();

    QFile list_nom_rec("Listado.txt");
    if(!list_nom_rec.open(QIODevice::ReadOnly))
        /**
         * @brief QMessageBox::information
         * Informa que el recetario esta vacio, por lo que no hay recetas para ver.
         */
        QMessageBox::information(0,"Error de lectura","Su recetario se encuentra vacío.");

    while(!list_nom_rec.atEnd()){
        ui->listWidget->addItem(list_nom_rec.readLine());
    }

    list_nom_rec.close();
}

/**
 * @brief NewReceta::~NewReceta
 * Destructor de la clase.
 */
VerReceta::~VerReceta()
{
    delete ui;
}

/**
 * @brief VerReceta::on_Abrir_clicked
 *
 */
void VerReceta::on_Abrir_clicked()
{
    ui->listWidget->setFocus(); /** <Si no hay receta seleccionada y se clickea "Abrir Receta", se despliega la primera en la lista.*/
    //Si ninguno está seleccionado se abre por defecto. Si no existiera el programa termina de forma inesperada.

    if (ui->listWidget->count()==0)
        /**
         * @brief QMessageBox::information
         * Advierte que el recetario esta vacio.
         */
        QMessageBox::information(0,"Listado Vacio","No tiene recetas ingresadas en su recetario.");
    else{

        QString nombre=(ui->listWidget->currentItem()->text()).trimmed(); /** <Guarda el nombre de la receta seleccionada del listado elimminando el salto de linea.*/
        QFile archivo("Ingredientes/"+nombre+"_ing.txt"); /** <Selecciona el archivo de ingredientes que corresponde con la receta.*/
        QFile file("Procedimiento/"+nombre+".txt"); /** <Selecciona el archivo de procedimiento que corresponde con la receta.*/

        if(!file.open(QIODevice::ReadOnly) || !archivo.open(QIODevice::ReadOnly))
            /**
             * @brief QMessageBox::information
             * Advierte un error de lectura o escritura.
             */
            QMessageBox::information(0,"Error de lectura","Archivo no encontrado.\nVerifique escritura.");

        ui->VerNombre->setText(nombre);

        QTextStream in(&file);
        QTextStream in2(&archivo);
        ui->VerPreparacion->setText(in2.readAll()); /** <Despliega por interfaz grafica el archivo de procedimiento que corresponde con la receta.*/
        ui->VerIngredientes->setText(in.readAll()); /** <Despliega por interfaz grafica el archivo de ingredientes que corresponde con la receta.*/
        ui->VerNombre->show(); /** <Despliega el nombre de la receta.*/
    }

}

/**
 * @brief VerReceta::on_Youtube_clicked
 * Busca una receta en la pagina web de YouTube.
 */
void VerReceta::on_Youtube_clicked()
{
    ui->listWidget->setFocus(); /** <Si no hay receta seleccionada y se clickea "Bucar en YouTube", se busca la primera en la lista.*/
    //Si ninguno está seleccionado se abre por defecto. Si no existiera el programa termina de forma inesperada.

    if (ui->listWidget->count()==0)
        /**
         * @brief QMessageBox::information
         * Advierte que el recetario esta vacio.
         */
        QMessageBox::information(0,"Listado Vacio","No tiene recetas ingresadas en su recetario.");
    else{
        QString nombre=(ui->listWidget->currentItem()->text()); /** <Guarda el nombre de la receta seleccionada del listado.*/
        QString youtube=nombre.replace(" ","+").trimmed(); /** <Reemplaza los espacios(" ") por signos mas (+) y eliminando el salto de linea del final del nombre.*/ //trimmed es para quitarle el \n
        QDesktopServices::openUrl(QUrl("https://www.youtube.com/results?search_query="+youtube+" receta")); /** <Abre el navegador con los resultados de la busqueda en la pagina web YouTube con la receta seleccionada.*/
    }
}

/**
 * @brief VerReceta::on_Eliminar_clicked
 * Eliminar la receta seleccionada.
 */
void VerReceta::on_Eliminar_clicked()
{
    ui->listWidget->setFocus();//Si ninguno está seleccionado se abre por defecto. Si no existiera el programa termina de forma inesperada.
    if (ui->listWidget->count()==0)
        /**
         * @brief QMessageBox::information
         * Advierte que el recetario esta vacio.
         */
        QMessageBox::information(0,"Listado Vacio","No tiene recetas ingresadas en su recetario.");
    else{
        /**
     * @brief guardarreceta
     * Verifica que esta seguro de realizar la accion de eliminar la receta seleccionada.
     */
    QMessageBox guardarreceta(QMessageBox::NoIcon,
        tr("Eliminar"),
        tr("¿Está seguro que desea eliminar la receta?"),
        QMessageBox::Yes | QMessageBox::No,this);
        guardarreceta.setButtonText(QMessageBox::Yes, tr("Sí"));
        guardarreceta.setButtonText(QMessageBox::No, tr("No"));
        if(guardarreceta.exec() == QMessageBox::Yes)
            {
            QString nombre=(ui->listWidget->currentItem()->text()).trimmed(); /** <Guarda el nombre de la receta seleccionada del listado eliminando el salto de linea.*/
            QFile archivo("Ingredientes/"+nombre+"_ing.txt"); /** <Selecciona el archivo de ingredientes que corresponde con la receta.*/
            QFile file("Procedimiento/"+nombre+".txt"); /** <Selecciona el archivo de procedimiento que corresponde con la receta.*/
            ui->listWidget->takeItem(ui->listWidget->currentRow()); /** < Elimina el nombre del listado de recetas.*/ //Elimina desde el qlistwidget
            file.remove(); /** <Elimina el archivo de procedimiento que corresponde con la receta.*/ //elimina el .txt
            archivo.remove(); /** <Elimina el archivo de ingredientes que corresponde con la receta.*/
            ui->VerPreparacion->clear(); /** <Borra el contenido de la preparacion de la visualizacion por interfaz grafica, esto en caso de ser previamente abierta la receta.*/
            ui->VerIngredientes->clear(); /** <Borra el contenido de los ingredientes de la visualizacion por interfaz grafica, esto en caso de ser previamente abierta la receta.*/

            /** <Se borra el nombre de la receta del listado de recetas a traves de un archivo temporal.*/
            QFile lista("Listado.txt");
            QTextStream in(&lista);
            QFile Temp("Listado2.txt");
            if(!lista.open(QFile::ReadOnly))
                QMessageBox::information(0,"Error de lectura","Archivo no encontrado.\nVerifique escritura.");
            if(!Temp.open(QFile::Append | QFile::Text))
                QMessageBox::information(0,"Error de lectura","Archivo no encontrado.\nVerifique escritura.");
            QTextStream out(&Temp);
            while (!in.atEnd())
                {
                QString line = in.readLine();
                if (!line.contains(nombre))
                    out << line+'\n'; /** <Verifica que no sea el nombre de la receta que se desea eliminar.*/
                }
                Temp.flush(); /** <Guarda los nombres de las recetas que no fueron eleccionadas para eliminar.*/
                lista.close();
                lista.remove(); /** <Elimina el listado viejo.*/
                Temp.rename("Listado.txt"); /** <Renombra el listado nuevo.*/
                Temp.close(); /** <Cierra el listado nuevo.*/
            }
            else
                guardarreceta.close();
    }
}

/**
 * @brief VerReceta::on_Volver_released
 * Regresa a la ventana principal de opciones.
 * Cierra la ventana de visualizacion de recetas.
 */
void VerReceta::on_Volver_released()
{
    this->close();
}
